def test_allowed_files(client):
    route = f"/opengeodeweb_back/allowed_files"
    response = client.post(route)
    assert response.status_code == 200


def test_root(client):
    route = f"/"
    response = client.post(route)
    assert response.status_code == 200


def test_healthcheck(client):
    route = f"/pegghy_back/healthcheck"
    response = client.get(route)
    assert response.status_code == 200
    message = response.json["message"]
    assert type(message) is str
    assert message == "healthy"



# Third parties
from opengeodeweb_back.app import app, run_server

from pegghy_back.routes import blueprint_pegghy

app.register_blueprint(
    blueprint_pegghy.routes,
    url_prefix="/pegghy_back",
    name="pegghy_back",
)


def run_pegghy_server() -> None:
    run_server()


if __name__ == "__main__":
    run_pegghy_server()



# Standard library imports
import os

# Third party imports
import flask
import flask_cors
import json

schemas = os.path.join(os.path.dirname(__file__), "schemas")

with open(os.path.join(schemas, "healthcheck.json"), "r") as file:
    healthcheck_json = json.load(file)

routes = flask.Blueprint("pegghy_routes", __name__)
flask_cors.CORS(routes)


@routes.route(healthcheck_json["route"], methods=healthcheck_json["methods"])
def healthcheck():
    return flask.make_response({"message": "healthy"}, 200)
